@@ -1,4 +1,4 @@
 ;;
 ;; This is a cushion module to use R7RS (scheme repl) from Gauche
 ;;
-(define-module scheme.repl (use r7rs))
+(define-module scheme.repl (use r7rs-setup))
